<?php

declare(strict_types=1);

use LidoNation\Adapayments\App\Enums\CurrencyEnum;
use LidoNation\Adapayments\App\Services\AdaUsdQuoteService;

if (! function_exists('ada_to_usd')) {
    function ada_to_usd(int|float $amount)
    {
        $rateInstance = new AdaUsdQuoteService(CurrencyEnum::ADA, CurrencyEnum::USD);

        return $rateInstance->rate;
    }
}

if (! function_exists('usd_to_ada')) {
    function usd_to_ada(int|float $amount)
    {
        $rateInstance = new AdaUsdQuoteService(CurrencyEnum::USD, CurrencyEnum::ADA);

        return $rateInstance->rate;
    }
}

if (! function_exists('env')) {
    /**
     * Gets the value of an environment variable. Supports boolean, empty and null.
     *
     * @param string $key
     * @param mixed|null $default
     * @return mixed
     */
    function env(string $key, mixed $default = null): mixed
    {
        $value = $_ENV[$key];

        if ($value === false) {
            return value($default);
        }

        switch (strtolower($value)) {
            case 'true':
            case '(true)':
                return true;

            case 'false':
            case '(false)':
                return false;

            case 'empty':
            case '(empty)':
                return '';

            case 'null':
            case '(null)':
                return null;
        }

        if ( str_starts_with($value, '"') && str_ends_with($value, '"')) {
            return substr($value, 1, -1);
        }

        return $value;
    }
}
